@@ -12,6 +12,7 @@
 # pylint: disable=protected-access
 
 """Circuit manipulation tools"""
+import numbers
 from qiskit import QuantumCircuit
 
 
@@ -32,15 +33,16 @@ def deflate_circuit(input_circ):
     num_reduced_qubits = len(active_qubits)
     num_reduced_clbits = len(active_clbits)
 
-    active_map = {}
+    active_qubit_map = {}
+    active_bit_map = {}
     for idx, val in enumerate(
         sorted(active_qubits, key=lambda x: input_circ.find_bit(x).index)
     ):
-        active_map[val] = idx
+        active_qubit_map[val] = idx
     for idx, val in enumerate(
         sorted(active_clbits, key=lambda x: input_circ.find_bit(x).index)
     ):
-        active_map[val] = idx
+        active_bit_map[val] = idx
 
     new_qc = QuantumCircuit(num_reduced_qubits, num_reduced_clbits)
     for item in input_circ.data:
@@ -50,10 +52,10 @@ def deflate_circuit(input_circ):
         if any(used_active_set):
             ref = getattr(new_qc, item[0].name)
             params = item[0].params
-            qargs = [new_qc.qubits[active_map[qubit]] for qubit in used_active_set]
-            cargs = [new_qc.clbits[active_map[clbit]] for clbit in item[2]]
+            qargs = [new_qc.qubits[active_qubit_map[qubit]] for qubit in used_active_set]
+            cargs = [new_qc.clbits[active_bit_map[clbit]] for clbit in item[2]]
             ref(*params, *qargs, *cargs)
-
+    new_qc.global_phase = input_circ.global_phase
     return new_qc
 
 
@@ -81,3 +83,34 @@ def active_bits(input_circ):
                 active_clbits.add(clbit)
 
     return active_qubits, active_clbits
+
+
+def inflate_circuit(input_circ, layout, backend):
+    """Inflate a circuit to execute on a backend.
+
+    Parameters:
+        input_circ (QuantumCircuit): Input circuit.
+        layout (list): List of best qubits for layout
+        backend (int or BackendV1 or BackendV2): An IBM Quantum backend instance
+                                                 or integer specifying number of
+                                                 qubits
+
+    Returns:
+        QuantumCircuit: Inflated circuit.
+
+    Notes:
+        Requires a circuit with flatten qregs and cregs.
+    """
+    if isinstance(backend, numbers.Integral):
+        num_qubits = backend
+    else:
+        num_qubits = backend.configuration().num_qubits
+    new_qc = QuantumCircuit(num_qubits, input_circ.num_clbits)
+    for item in input_circ.data:
+        ref = getattr(new_qc, item[0].name)
+        params = item[0].params
+        qargs = [layout[input_circ.find_bit(idx).index] for idx in item[1]]
+        cargs = item[2]
+        ref(*params, *qargs, *cargs)
+    new_qc.global_phase = input_circ.global_phase
+    return new_qc
